@@ -1,5 +1,5 @@
 from metadata_extractor.builders.rdbms.rdbms_builder_abstract import RDBMSBuilder
-from metadata_extractor.models.enum.builder_enum import RDBMSBuilderName
+from metadata_extractor.models.enum.db_engine_enum import DBEngine
 from metadata_extractor.builders.rdbms.postgresql_builder import PostgresqlBuilder
 from metadata_extractor.builders.rdbms.mysql_builder import MysqlBuilder
 
@@ -8,8 +8,8 @@ class RDBMSBuilderFactory:
     @staticmethod
     def create(name: str) -> RDBMSBuilder:
         switcher = {
-            RDBMSBuilderName.postgresql.name: PostgresqlBuilder(),
-            RDBMSBuilderName.mysql.name: MysqlBuilder()
+            DBEngine.postgresql.name: PostgresqlBuilder(),
+            DBEngine.mysql.name: MysqlBuilder()
         }
 
         builder_obj = switcher.get(name, None)
