@@ -1,15 +1,15 @@
 from metadata_extractor.extractor.rdbms.rdbms_extractor_abstract import RDBMSExtractor
 from metadata_extractor.extractor.rdbms.postgresql_extractor import PostgresqlExtractor
 from metadata_extractor.extractor.rdbms.mysql_extractor import MysqlExtractor
-from metadata_extractor.models.enum.extractor_enum import RDBMSExtractorName
+from metadata_extractor.models.enum.db_engine_enum import DBEngine
 
 
 class RDBMSExtractorFactory:
     @staticmethod
     def create(name: str) -> RDBMSExtractor:
         switcher = {
-            RDBMSExtractorName.postgresql.name: PostgresqlExtractor(),
-            RDBMSExtractorName.mysql.name: MysqlExtractor()
+            DBEngine.postgresql.name: PostgresqlExtractor(),
+            DBEngine.mysql.name: MysqlExtractor()
         }
 
         builder_obj = switcher.get(name, None)
